==> openGion_dev_5.1.1.0.zip: opengion/uap/webapps/ge/db/mysql/sql/01_TABLE/GE55S.sql <==
/**************************************************************************/
/* GE55 ( 出力先マスタ )                                                  */
/*                                                                        */
/* Created : 2009/11/17 09:27:38                                          */
/**************************************************************************/
CREATE TABLE GE55 (
   SYSTEM_ID     VARCHAR(10)                 NOT NULL      /* 10  システムID         */
 , PRTID         VARCHAR(20)                 NOT NULL      /* 20  プリンタID         */
 , PRTNM         VARCHAR(100)                              /* 30  プリンタ名         */
 , PORTNM        VARCHAR(30)                               /* 40  ポート名           */
 , COMMENTS      VARCHAR(500)                              /* 50  コメント           */
 , RELEASE_NOTES VARCHAR(120)                              /* 120 リリースノート     */
 , RDC_CODE      VARCHAR(20)                               /* 130 設変番号           */
 , PRT_GRP       VARCHAR(20)                               /* 140 プリンターグループ */
 , HOST_ID       VARCHAR(50)                               /* 150 ホスト             */
 , FGJ           VARCHAR(1)      DEFAULT '1' NOT NULL      /* 810 状態フラグ         */
 , DYSET         VARCHAR(14)                               /* 820 登録日時           */
 , PGSET         VARCHAR(10)                               /* 830 作成PG             */
 , PGPSET        VARCHAR(10)                               /* 840 作成親PG           */
 , USRSET        VARCHAR(10)                               /* 850 作成社員           */
 , DYUPD         VARCHAR(14)                               /* 860 更新日時           */
 , PGUPD         VARCHAR(10)                               /* 870 更新PG             */
 , PGPUPD        VARCHAR(10)                               /* 880 更新親PG           */
 , USRUPD        VARCHAR(10)                               /* 890 更新者             */
);

==> openGion_dev_5.1.6.0.zip: opengion/uap/webapps/ge/db/mysql/sql/01_TABLE/GE55S.sql <==
/**************************************************************************/
/* GE55 ( 出力先マスタ )                                                  */
/*                                                                        */
/* Created : 2010/05/07 16:07:38                                          */
/**************************************************************************/
CREATE TABLE GE55 (
   SYSTEM_ID     VARCHAR(10)                 NOT NULL      /* 10  システムID         */
 , PRTID         VARCHAR(20)                 NOT NULL      /* 20  プリンタID         */
 , PRTNM         VARCHAR(100)                              /* 30  プリンタ名         */
 , PORTNM        VARCHAR(30)                               /* 40  ポート名           */
 , COMMENTS      TEXT                                      /* 50  コメント           */
 , RELEASE_NOTES VARCHAR(120)                              /* 120 リリースノート     */
 , RDC_CODE      VARCHAR(20)                               /* 130 設変番号           */
 , PRT_GRP       VARCHAR(20)                               /* 140 プリンターグループ */
 , HOST_ID       VARCHAR(50)                               /* 150 ホスト             */
 , FGJ           VARCHAR(1)      DEFAULT '1' NOT NULL      /* 810 状態フラグ         */
 , DYSET         VARCHAR(14)                               /* 820 登録日時           */
 , PGSET         VARCHAR(10)                               /* 830 作成PG             */
 , PGPSET        VARCHAR(10)                               /* 840 作成親PG           */
 , USRSET        VARCHAR(10)                               /* 850 作成社員           */
 , DYUPD         VARCHAR(14)                               /* 860 更新日時           */
 , PGUPD         VARCHAR(10)                               /* 870 更新PG             */
 , PGPUPD        VARCHAR(10)                               /* 880 更新親PG           */
 , USRUPD        VARCHAR(10)                               /* 890 更新者             */
);
